[−][src]Enum unicode_types::zanabazar_square::ZanabazarSquare
An enum to represent all characters in the ZanabazarSquare block.
Variants
LetterA\u{11a00}: '𑨀'
VowelSignI\u{11a01}: '𑨁'
VowelSignUe\u{11a02}: '𑨂'
VowelSignU\u{11a03}: '𑨃'
VowelSignE\u{11a04}: '𑨄'
VowelSignOe\u{11a05}: '𑨅'
VowelSignO\u{11a06}: '𑨆'
VowelSignAi\u{11a07}: '𑨇'
VowelSignAu\u{11a08}: '𑨈'
VowelSignReversedI\u{11a09}: '𑨉'
VowelLengthMark\u{11a0a}: '𑨊'
LetterKa\u{11a0b}: '𑨋'
LetterKha\u{11a0c}: '𑨌'
LetterGa\u{11a0d}: '𑨍'
LetterGha\u{11a0e}: '𑨎'
LetterNga\u{11a0f}: '𑨏'
LetterCa\u{11a10}: '𑨐'
LetterCha\u{11a11}: '𑨑'
LetterJa\u{11a12}: '𑨒'
LetterNya\u{11a13}: '𑨓'
LetterTta\u{11a14}: '𑨔'
LetterTtha\u{11a15}: '𑨕'
LetterDda\u{11a16}: '𑨖'
LetterDdha\u{11a17}: '𑨗'
LetterNna\u{11a18}: '𑨘'
LetterTa\u{11a19}: '𑨙'
LetterTha\u{11a1a}: '𑨚'
LetterDa\u{11a1b}: '𑨛'
LetterDha\u{11a1c}: '𑨜'
LetterNa\u{11a1d}: '𑨝'
LetterPa\u{11a1e}: '𑨞'
LetterPha\u{11a1f}: '𑨟'
LetterBa\u{11a20}: '𑨠'
LetterBha\u{11a21}: '𑨡'
LetterMa\u{11a22}: '𑨢'
LetterTsa\u{11a23}: '𑨣'
LetterTsha\u{11a24}: '𑨤'
LetterDza\u{11a25}: '𑨥'
LetterDzha\u{11a26}: '𑨦'
LetterZha\u{11a27}: '𑨧'
LetterZa\u{11a28}: '𑨨'
LetterDashA\u{11a29}: '𑨩'
LetterYa\u{11a2a}: '𑨪'
LetterRa\u{11a2b}: '𑨫'
LetterLa\u{11a2c}: '𑨬'
LetterVa\u{11a2d}: '𑨭'
LetterSha\u{11a2e}: '𑨮'
LetterSsa\u{11a2f}: '𑨯'
LetterSa\u{11a30}: '𑨰'
LetterHa\u{11a31}: '𑨱'
LetterKssa\u{11a32}: '𑨲'
FinalConsonantMark\u{11a33}: '𑨳'
SignVirama\u{11a34}: '𑨴'
SignCandrabindu\u{11a35}: '𑨵'
SignCandrabinduWithOrnament\u{11a36}: '𑨶'
SignCandraWithOrnament\u{11a37}: '𑨷'
SignAnusvara\u{11a38}: '𑨸'
SignVisarga\u{11a39}: '𑨹'
ClusterDashInitialLetterRa\u{11a3a}: '𑨺'
ClusterDashFinalLetterYa\u{11a3b}: '𑨻'
ClusterDashFinalLetterRa\u{11a3c}: '𑨼'
ClusterDashFinalLetterLa\u{11a3d}: '𑨽'
ClusterDashFinalLetterVa\u{11a3e}: '𑨾'
InitialHeadMark\u{11a3f}: '𑨿'
ClosingHeadMark\u{11a40}: '𑩀'
MarkTsheg\u{11a41}: '𑩁'
MarkShad\u{11a42}: '𑩂'
MarkDoubleShad\u{11a43}: '𑩃'
MarkLongTsheg\u{11a44}: '𑩄'
InitialDoubleDashLinedHeadMark\u{11a45}: '𑩅'
ClosingDoubleDashLinedHeadMark\u{11a46}: '𑩆'
Subjoiner\u{11a47}: '𑩇'
Methods
impl ZanabazarSquare[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case